@@ -1,26 +1,28 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2022, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2022, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 import struct
 import os
 import string
+import platform
+from typing import Dict, Tuple, Optional, AnyStr, Iterable
 
 import chipsec.file
 
@@ -89,100 +91,100 @@ BIT61 = 0x2000000000000000
 BIT62 = 0x4000000000000000
 BIT63 = 0x8000000000000000
 
-BOUNDARY_1KB   = 0x400
-BOUNDARY_2KB   = 0x800
-BOUNDARY_4KB   = 0x1000
-BOUNDARY_1MB   = 0x100000
-BOUNDARY_2MB   = 0x200000
-BOUNDARY_4MB   = 0x400000
-BOUNDARY_8MB   = 0x800000
-BOUNDARY_16MB  = 0x1000000
-BOUNDARY_32MB  = 0x2000000
-BOUNDARY_64MB  = 0x4000000
+BOUNDARY_1KB = 0x400
+BOUNDARY_2KB = 0x800
+BOUNDARY_4KB = 0x1000
+BOUNDARY_1MB = 0x100000
+BOUNDARY_2MB = 0x200000
+BOUNDARY_4MB = 0x400000
+BOUNDARY_8MB = 0x800000
+BOUNDARY_16MB = 0x1000000
+BOUNDARY_32MB = 0x2000000
+BOUNDARY_64MB = 0x4000000
 BOUNDARY_128MB = 0x8000000
 BOUNDARY_256MB = 0x10000000
 BOUNDARY_512MB = 0x20000000
-BOUNDARY_1GB   = 0x40000000
-BOUNDARY_2GB   = 0x80000000
-BOUNDARY_4GB   = 0x100000000
+BOUNDARY_1GB = 0x40000000
+BOUNDARY_2GB = 0x80000000
+BOUNDARY_4GB = 0x100000000
 
-ALIGNED_4KB   = 0xFFF
-ALIGNED_1MB   = 0xFFFFF
-ALIGNED_8MB   = 0x7FFFFF
-ALIGNED_64MB  = 0x3FFFFFF
+ALIGNED_4KB = 0xFFF
+ALIGNED_1MB = 0xFFFFF
+ALIGNED_8MB = 0x7FFFFF
+ALIGNED_64MB = 0x3FFFFFF
 ALIGNED_128MB = 0x7FFFFFF
 ALIGNED_256MB = 0xFFFFFFF
 
-MASK_8b  = 0xFF
+MASK_8b = 0xFF
 MASK_16b = 0xFFFF
 MASK_32b = 0xFFFFFFFF
 MASK_64b = 0xFFFFFFFFFFFFFFFF
 
 
-def bit(bit_num):
+def bit(bit_num: int) -> int:
     return int(1 << bit_num)
 
 
-def is_set(val, bit_mask):
+def is_set(val: int, bit_mask: int) -> bool:
     return bool(val & bit_mask != 0)
 
 
-def scan_single_bit_mask(bit_mask):
+def scan_single_bit_mask(bit_mask: int) -> Optional[int]:
     for bit_num in range(0, 7):
         if bit_mask >> bit_num == 1:
             return bit_num
+    return None
 
 
-#
-# Compression Types
-#
-COMPRESSION_TYPE_NONE = 0
-COMPRESSION_TYPE_TIANO = 1
-COMPRESSION_TYPE_UEFI = 2
-COMPRESSION_TYPE_LZMA  = 3
-COMPRESSION_TYPE_BROTLI = 4
-COMPRESSION_TYPE_EFI_STANDARD = 5
-COMPRESSION_TYPE_UNKNOWN = 6
-COMPRESSION_TYPES_ALGORITHMS = [COMPRESSION_TYPE_LZMA, COMPRESSION_TYPE_TIANO, COMPRESSION_TYPE_UEFI, COMPRESSION_TYPE_BROTLI, COMPRESSION_TYPE_NONE]
-COMPRESSION_TYPES = [COMPRESSION_TYPE_NONE, COMPRESSION_TYPE_TIANO, COMPRESSION_TYPE_UEFI, COMPRESSION_TYPE_LZMA, COMPRESSION_TYPE_BROTLI, COMPRESSION_TYPE_EFI_STANDARD, COMPRESSION_TYPE_UNKNOWN]
-
-def DB(val):
+def DB(val: int) -> bytes:
     return struct.pack('<B', val)
-def DW(val):
+
+
+def DW(val: int) -> bytes:
     return struct.pack('<H', val)
-def DD(val):
+
+
+def DD(val: int) -> bytes:
     return struct.pack('<L', val)
-def DQ(val):
+
+
+def DQ(val: int) -> bytes:
     return struct.pack('<Q', val)
 
-SIZE2FORMAT = {
+
+SIZE2FORMAT: Dict[int, str] = {
     1: 'B',
     2: 'H',
     4: 'I',
     8: 'Q'
 }
 
-def bytestostring(mbytes):
-    if isinstance(mbytes, bytes):
+
+def bytestostring(mbytes: AnyStr) -> str:
+    if isinstance(mbytes, bytes) or isinstance(mbytes, bytearray):
         return mbytes.decode("latin_1")
     else:
         return mbytes
 
-def stringtobytes(mstr):
+
+def stringtobytes(mstr: AnyStr) -> bytes:
     if isinstance(mstr, str):
         return mstr.encode("latin_1")
     else:
         return mstr
 
-def pack1(value, size):
+
+def pack1(value: int, size: int) -> bytes:
     """Shortcut to pack a single value into a string based on its size."""
     return struct.pack(SIZE2FORMAT[size], value)
 
-def unpack1(string, size):
+
+def unpack1(string: bytes, size: int) -> int:
     """Shortcut to unpack a single value from a string based on its size."""
     return struct.unpack(SIZE2FORMAT[size], string)[0]
 
-def get_version():
+
+def get_version() -> str:
     version_strs = []
     chipsec_folder = os.path.abspath(chipsec.file.get_main_dir())
     for fname in sorted([x for x in os.listdir(os.path.join(chipsec_folder, "chipsec")) if x.startswith('VERSION')]):
@@ -191,17 +193,25 @@ def get_version():
             version_strs.append(verFile.read().strip())
     return '-'.join(version_strs)
 
-def is_printable(seq):
+
+def os_version() -> Tuple[str, str, str, str]:
+    return platform.system(), platform.release(), platform.version(), platform.machine()
+
+
+def is_printable(seq) -> bool:
     return set(seq).issubset(set(string.printable))
 
-def is_hex(maybe_hex):
+
+def is_hex(maybe_hex: Iterable) -> bool:
     return all(char in string.hexdigits for char in maybe_hex)
 
-def is_all_ones(value, size, width=8):
-    mask = (1<<(size * width)) - 1
+
+def is_all_ones(value: int, size: int, width: int = 8) -> bool:
+    mask = (1 << (size * width)) - 1
     return (mask == (mask & value))
 
-def get_message():
+
+def get_message() -> str:
     msg_str = ""
     chipsec_folder = os.path.abspath(chipsec.file.get_main_dir())
     msg_file = os.path.join(chipsec_folder, "chipsec", "MESSAGE")
@@ -209,3 +219,8 @@ def get_message():
         with open(msg_file, "r") as msgFile:
             msg_str = msgFile.read()
     return msg_str
+
+
+class ARCH_VID:
+    INTEL = 0x8086
+    AMD = 0x1022
