@@ -22,7 +22,6 @@ import os
 import platform
 import struct
 import subprocess
-import shutil
 
 import chipsec
 import chipsec.defines
@@ -30,48 +29,43 @@ from chipsec.exceptions import OsHelperError, UnimplementedAPIError
 from chipsec.helper.basehelper import Helper
 from chipsec.logger import logger
 
-MSGBUS_MDR_IN_MASK          = 0x1
-MSGBUS_MDR_OUT_MASK         = 0x2
+MSGBUS_MDR_IN_MASK = 0x1
+MSGBUS_MDR_OUT_MASK = 0x2
 
-IOCTL_RDPCI                 = 0xc00c7001
-IOCTL_WRPCI                 = 0xc00c7002
-IOCTL_RDMMIO                = 0xc0187003
-IOCTL_WRMMIO                = 0xc0187004
-IOCTL_RDCR                  = 0xc0107005
-IOCTL_WRCR                  = 0xc0107006
-IOCTL_RDIO                  = 0xc0187007
-IOCTL_WRIO                  = 0xc0187008
-IOCTL_CPUID                 = 0xc0207009
-IOCTL_RDMSR                 = 0xc018700a
-IOCTL_WRMSR                 = 0xc018700b
-IOCTL_SWSMI                 = 0xc038700c
-IOCTL_HYPERCALL             = 0xc060700d
-IOCTL_MSGBUS_SEND_MESSAGE   = 0xc028700e
-IOCTL_CPU_DESCRIPTOR_TABLE  = 0xc038700f
-IOCTL_ALLOC_PHYSMEM         = 0xc0207010
+IOCTL_RDPCI = 0xc00c7001
+IOCTL_WRPCI = 0xc00c7002
+IOCTL_RDMMIO = 0xc0187003
+IOCTL_WRMMIO = 0xc0187004
+IOCTL_RDCR = 0xc0107005
+IOCTL_WRCR = 0xc0107006
+IOCTL_RDIO = 0xc0187007
+IOCTL_WRIO = 0xc0187008
+IOCTL_CPUID = 0xc0207009
+IOCTL_RDMSR = 0xc018700a
+IOCTL_WRMSR = 0xc018700b
+IOCTL_SWSMI = 0xc038700c
+IOCTL_HYPERCALL = 0xc060700d
+IOCTL_MSGBUS_SEND_MESSAGE = 0xc028700e
+IOCTL_CPU_DESCRIPTOR_TABLE = 0xc038700f
+IOCTL_ALLOC_PHYSMEM = 0xc0207010
 #IOCTL_LOAD_UCODE_PATCH      = 0xc0067011
 
 # Format for the IOCTL structures. See chipsec_ioctl.h for the complete
 # definition.
-_pci_msg_t_fmt       = "BBBHBI"
-_mmio_msg_t_fmt      = "QQB"
-_io_msg_t_fmt        = "QQQ"
-_cr_msg_t_fmt        = "IQ"
-_msr_msg_t_fmt       = "QQQ"
-_cpuid_msg_t_fmt     = "QQQQ"
-_smi_msg_t_fmt       = "QQQQQQQ"
+_pci_msg_t_fmt = "BBBHBI"
+_mmio_msg_t_fmt = "QQB"
+_io_msg_t_fmt = "QQQ"
+_cr_msg_t_fmt = "IQ"
+_msr_msg_t_fmt = "QQQ"
+_cpuid_msg_t_fmt = "QQQQ"
+_smi_msg_t_fmt = "QQQQQQQ"
 _hypercall_msg_t_fmt = "QQQQQQQQQQQQ"
-_msgbus_msg_t_fmt    = "QQQQQ"
-_cpudes_msg_t_fmt    = "QQQQQQQ"
+_msgbus_msg_t_fmt = "QQQQQ"
+_cpudes_msg_t_fmt = "QQQQQQQ"
 #_ucodeh_msg_t_fmt    = "BH"
 _alloc_mem_msg_t_fmt = "QQQQ"
 
 
-LZMA  = os.path.join(chipsec.file.TOOLS_DIR, "compression", "bin", "LzmaCompress")
-TIANO = os.path.join(chipsec.file.TOOLS_DIR, "compression", "bin", "TianoCompress")
-EFI   = os.path.join(chipsec.file.TOOLS_DIR, "compression", "bin", "TianoCompress")
-BROTLI = os.path.join(chipsec.file.TOOLS_DIR, "compression", "bin", "Brotli")
-
 class OSXHelper(Helper):
 
     DEVICE_NAME = "/dev/chipsec"
@@ -79,17 +73,14 @@ class OSXHelper(Helper):
 
     def __init__(self):
         super(OSXHelper, self).__init__()
-        self.os_system  = platform.system()
+        self.os_system = platform.system()
         self.os_release = platform.release()
         self.os_version = platform.version()
         self.os_machine = platform.machine()
-        self.os_uname   = platform.uname()
+        self.os_uname = platform.uname()
         self.dev_fh = None
         self.name = "OSXHelper"
 
-    decompression_oder_type1 = [chipsec.defines.COMPRESSION_TYPE_TIANO, chipsec.defines.COMPRESSION_TYPE_UEFI]
-    decompression_oder_type2 = [chipsec.defines.COMPRESSION_TYPE_TIANO, chipsec.defines.COMPRESSION_TYPE_UEFI, chipsec.defines.COMPRESSION_TYPE_LZMA, chipsec.defines.COMPRESSION_TYPE_BROTLI]
-
     def load_driver(self):
         driver_path = os.path.join(chipsec.file.get_main_dir(), "chipsec",
                                    "helper", "osx", self.DRIVER_NAME)
@@ -105,11 +96,11 @@ class OSXHelper(Helper):
             if logger().DEBUG:
                 logger().log("Module {} loaded successfully".format(self.DRIVER_NAME))
         else:
-            logger().error("Failed to load the module {}".format(self.DRIVER_NAME))
+            logger().log_error("Failed to load the module {}".format(self.DRIVER_NAME))
         self.driverpath = driver_path
 
     def create(self, start_driver):
-        #self.init(start_driver)
+        # self.init(start_driver)
         if logger().DEBUG:
             logger().log("[helper] OSX Helper created")
         return True
@@ -177,24 +168,26 @@ class OSXHelper(Helper):
         ret = self.mem_read_block((addr_hi << 32) | addr_lo, size)
         return ret
 
-    def read_pci_reg( self, bus, device, function, offset, size = 4 ):
+    def read_pci_reg(self, bus, device, function, offset, size=4):
         data = struct.pack(_pci_msg_t_fmt, bus, device, function, offset,
                            size, 0)
         try:
             ret = self.ioctl(IOCTL_RDPCI, data)
         except IOError:
-            if logger().DEBUG: logger().error("IOError")
+            if logger().DEBUG:
+                logger().log_error("IOError")
             return None
         x = struct.unpack(_pci_msg_t_fmt, ret)
         return x[5]
 
-    def write_pci_reg( self, bus, device, function, offset, value, size = 4 ):
+    def write_pci_reg(self, bus, device, function, offset, value, size=4):
         data = struct.pack(_pci_msg_t_fmt, bus, device, function, offset,
                            size, value)
         try:
             ret = self.ioctl(IOCTL_WRPCI, data)
         except IOError:
-            if logger().DEBUG: logger().error("IOError")
+            if logger().DEBUG:
+                logger().log_error("IOError")
 
     def read_mmio_reg(self, phys_address, size):
         data = struct.pack(_mmio_msg_t_fmt, phys_address, 0, size)
@@ -209,95 +202,13 @@ class OSXHelper(Helper):
     def getcwd(self):
         return os.getcwd()
 
-    def rotate_list(self, list, n):
-        return list[n:] + list[:n]
-
-    def unknown_decompress(self, CompressedFileName, OutputFileName):
-        failed_times = 0
-        for CompressionType in self.decompression_oder_type2:
-            res = self.decompress_file(CompressedFileName, OutputFileName, CompressionType)
-            if res == True:
-                self.rotate_list(self.decompression_oder_type2, failed_times)
-                break
-            else:
-                failed_times += 1
-        return res
-
-    def unknown_efi_decompress(self, CompressedFileName, OutputFileName):
-        failed_times = 0
-        for CompressionType in self.decompression_oder_type1:
-            res = self.decompress_file(CompressedFileName, OutputFileName, CompressionType)
-            if res == True:
-                self.rotate_list(self.decompression_oder_type1, failed_times)
-                break
-            else:
-                failed_times += 1
-        return res
-
-    #
-    # Compress binary file
-    #
-    def compress_file( self, FileName, OutputFileName, CompressionType ):
-        if not CompressionType in [i for i in chipsec.defines.COMPRESSION_TYPES]:
-            return False
-        encode_str = " -e -o {} ".format(OutputFileName)
-        if CompressionType == chipsec.defines.COMPRESSION_TYPE_NONE:
-            shutil.copyfile(FileName, OutputFileName)
-            return True
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_TIANO:
-            encode_str = TIANO + encode_str
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_UEFI:
-            encode_str = EFI + encode_str + "--uefi "
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_LZMA:
-            encode_str = LZMA + encode_str
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_BROTLI:
-            encode_str = BROTLI + encode_str
-        encode_str += FileName
-        data = subprocess.call(encode_str, shell=True)
-        if not data == 0 and logger().VERBOSE:
-            logger().error("Cannot decompress file({})".format(FileName))
-            return False
-        return True
-
-    #
-    # Decompress binary
-    #
-    def decompress_file( self, CompressedFileName, OutputFileName, CompressionType ):
-        if not CompressionType in [i for i in chipsec.defines.COMPRESSION_TYPES]:
-            return False
-        if CompressionType == chipsec.defines.COMPRESSION_TYPE_UNKNOWN:
-            data = self.unknown_decompress(CompressedFileName, OutputFileName)
-            return data
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_EFI_STANDARD:
-            data = self.unknown_efi_decompress(CompressedFileName, OutputFileName)
-            return data
-        decode_str = " -d -o {} ".format(OutputFileName)
-        if CompressionType == chipsec.defines.COMPRESSION_TYPE_NONE:
-            shutil.copyfile(CompressedFileName, OutputFileName)
-            return True
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_TIANO:
-            decode_str = TIANO + decode_str
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_UEFI:
-            decode_str = EFI + decode_str + "--uefi "
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_LZMA:
-            decode_str = LZMA + decode_str
-        elif CompressionType == chipsec.defines.COMPRESSION_TYPE_BROTLI:
-            decode_str = BROTLI + decode_str
-        decode_str += CompressedFileName
-        data = subprocess.call(decode_str, shell=True)
-        if not data == 0 and logger().VERBOSE:
-            logger().error("Cannot decompress file({})".format(CompressedFileName))
-            return False
-        return True
-
-
     def get_tool_info( self, tool_type ):
         raise NotImplementedError()
 
     #
     # Logical CPU count
     #
-    def get_threads_count (self):
+    def get_threads_count(self):
         import subprocess
         return int(subprocess.check_output("sysctl -n hw.ncpu", shell=True))
 
@@ -313,25 +224,28 @@ class OSXHelper(Helper):
 
     def delete_EFI_variable(self, name, guid):
         raise NotImplementedError()
+
     def native_delete_EFI_variable(self, name, guid):
         raise NotImplementedError()
 
     def list_EFI_variables(self):
         raise NotImplementedError()
+
     def native_list_EFI_variables(self):
         raise NotImplementedError()
 
     def get_EFI_variable(self, name, guid, attrs=None):
         raise NotImplementedError()
+
     def native_get_EFI_variable(self, name, guid, attrs=None):
         raise NotImplementedError()
 
     def set_EFI_variable(self, name, guid, data, datasize, attrs=None):
         raise NotImplementedError()
+
     def native_set_EFI_variable(self, name, guid, data, datasize, attrs=None):
         raise NotImplementedError()
 
-
     #########################################################
     # Port I/O
     #########################################################
@@ -347,7 +261,8 @@ class OSXHelper(Helper):
             else:
                 value = struct.unpack(_io_msg_t_fmt, out_buf)[2] & 0xffffffff
         except:
-            if logger().DEBUG: logger().error("DeviceIoControl did not return value of proper size {:x} (value = '{}')".format(size, out_buf))
+            if logger().DEBUG:
+                logger().log_error("DeviceIoControl did not return value of proper size {:x} (value = '{}')".format(size, out_buf))
         return value
 
     def write_io_port(self, io_port, value, size):
@@ -355,31 +270,31 @@ class OSXHelper(Helper):
         return self.ioctl(IOCTL_WRIO, in_buf)
 
     def read_cr(self, cpu_thread_id, cr_number):
-        #self.set_affinity(cpu_thread_id)
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_cr_msg_t_fmt, cr_number, 0)
         out_buf = self.ioctl(IOCTL_RDCR, in_buf)
         value = struct.unpack(_cr_msg_t_fmt, out_buf)[1]
         return value
 
     def write_cr(self, cpu_thread_id, cr_number, value):
-        #self.set_affinity(cpu_thread_id)
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_cr_msg_t_fmt, cr_number, value)
         return self.ioctl(IOCTL_WRCR, in_buf)
 
     def read_msr(self, thread_id, msr_addr):
-        #self.set_affinity(cpu_thread_id)
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_msr_msg_t_fmt, msr_addr, 0, 0)
         out_buf = self.ioctl(IOCTL_RDMSR, in_buf)
         value = struct.unpack(_msr_msg_t_fmt, out_buf)
         return (value[1], value[2])
 
     def write_msr(self, thread_id, msr_addr, eax, edx):
-        #self.set_affinity(cpu_thread_id)
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_msr_msg_t_fmt, msr_addr, 0, 0)
         return self.ioctl(IOCTL_WRMSR, in_buf)
 
     def get_descriptor_table(self, cpu_thread_id, desc_table_code):
-        #self.set_affinity(cpu_thread_id)
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_cpudes_msg_t_fmt, cpu_thread_id, desc_table_code, 0, 0, 0, 0, 0)
         out_buf = self.ioctl(IOCTL_CPU_DESCRIPTOR_TABLE, in_buf)
         (limit, base_hi, base_lo, pa_hi, pa_lo) = struct.unpack(_cpudes_msg_t_fmt, out_buf)[2:]
@@ -387,7 +302,7 @@ class OSXHelper(Helper):
         base = (base_hi << 32) + base_lo
         return (limit, base, pa)
 
-    def hypercall(self, rcx, rdx, r8, r9, r10, r11, rax, rbx, rdi, rsi, xmm_buffer ):
+    def hypercall(self, rcx, rdx, r8, r9, r10, r11, rax, rbx, rdi, rsi, xmm_buffer):
         in_buf = struct.pack(_hypercall_msg_t_fmt, rcx, rdx, r8, r9, r10, r11, rax, rbx, rdi, rsi, xmm_buffer, 0)
         out_buf = self.ioctl(IOCTL_HYPERCALL, in_buf)
         return struct.unpack(_hypercall_msg_t_fmt, out_buf)[11]
@@ -402,27 +317,27 @@ class OSXHelper(Helper):
         out_buf = self.ioctl(IOCTL_ALLOC_PHYSMEM, in_buf)
         return struct.unpack(_alloc_mem_msg_t_fmt, out_buf)[2:]
 
-    def msgbus_send_read_message( self, mcr, mcrx ):
+    def msgbus_send_read_message(self, mcr, mcrx):
         mdr_out = 0
-        in_buf  = struct.pack(_msgbus_msg_t_fmt, MSGBUS_MDR_OUT_MASK, mcr, mcrx, 0, mdr_out)
-        out_buf = self.ioctl( IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
-        mdr_out = struct.unpack( _msgbus_msg_t_fmt, out_buf)[4]
+        in_buf = struct.pack(_msgbus_msg_t_fmt, MSGBUS_MDR_OUT_MASK, mcr, mcrx, 0, mdr_out)
+        out_buf = self.ioctl(IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
+        mdr_out = struct.unpack(_msgbus_msg_t_fmt, out_buf)[4]
         return mdr_out
 
-    def msgbus_send_write_message( self, mcr, mcrx, mdr):
+    def msgbus_send_write_message(self, mcr, mcrx, mdr):
         mdr_out = 0
-        in_buf  = struct.pack(_msgbus_msg_t_fmt, MSGBUS_MDR_IN_MASK, mcr, mcrx, mdr, mdr_out)
-        out_buf = self.ioctl( IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
+        in_buf = struct.pack(_msgbus_msg_t_fmt, MSGBUS_MDR_IN_MASK, mcr, mcrx, mdr, mdr_out)
+        out_buf = self.ioctl(IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
         return
 
-    def msgbus_send_message( self, mcr, mcrx, mdr=None):
+    def msgbus_send_message(self, mcr, mcrx, mdr=None):
         mdr_out = 0
         if mdr is None:
             in_buf = struct.pack(_msgbus_msg_t_fmt, MSGBUS_MDR_OUT_MASK, mcr, mcrx, 0, mdr_out)
         else:
             in_buf = struct.pack(_msgbus_msg_t_fmt, (MSGBUS_MDR_IN_MASK | MSGBUS_MDR_OUT_MASK), mcr, mcrx, mdr, mdr_out)
-        out_buf = self.ioctl( IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
-        mdr_out = struct.unpack( _msgbus_msg_t_fmt, out_buf)[4]
+        out_buf = self.ioctl(IOCTL_MSGBUS_SEND_MESSAGE, in_buf)
+        mdr_out = struct.unpack(_msgbus_msg_t_fmt, out_buf)[4]
         return mdr_out
 
     def get_affinity(self):
@@ -431,8 +346,8 @@ class OSXHelper(Helper):
     def set_affinity(self, thread_id):
         raise NotImplementedError()
 
-    def send_sw_smi( self, cpu_thread_id, SMI_code_data, _rax, _rbx, _rcx, _rdx, _rsi, _rdi):
-        #self.set_affinity(cpu_thread_id)
+    def send_sw_smi(self, cpu_thread_id, SMI_code_data, _rax, _rbx, _rcx, _rdx, _rsi, _rdi):
+        # self.set_affinity(cpu_thread_id)
         in_buf = struct.pack(_smi_msg_t_fmt, SMI_code_data, _rax, _rbx, _rcx, _rdx, _rsi, _rdi)
         out_buf = self.ioctl(IOCTL_SWSMI, in_buf)
         ret = struct.unpack(_smi_msg_t_fmt, out_buf)
@@ -450,5 +365,6 @@ class OSXHelper(Helper):
     def retpoline_enabled(self):
         raise UnimplementedAPIError("retpoline_enabled")
 
+
 def get_helper():
     return OSXHelper()
