@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 #
 # Authors:
@@ -39,6 +39,10 @@ Registers used:
     - HSFS.FDV
     - FRAP.BRWA
 
+.. important::
+    - Some platforms may use alternate means of protecting these regions.
+      Consider this when assessing results.
+
 """
 
 from chipsec.module_common import BaseModule, ModuleResult, MTAG_BIOS
@@ -46,14 +50,19 @@ from chipsec.hal.spi import SPI, GBE, PLATFORM_DATA, ME, FLASH_DESCRIPTOR
 
 TAGS = [MTAG_BIOS]
 
+
 class spi_access(BaseModule):
 
     def __init__(self):
         BaseModule.__init__(self)
-        self.spi = SPI( self.cs )
+        self.spi = SPI(self.cs)
 
     def is_supported(self):
-        return True
+        if self.cs.register_has_field('HSFS', 'FDV') and self.cs.register_has_field('FRAP', 'BRWA'):
+            return True
+        self.logger.log_important('HSFS.FDV or FRAP.BRWA registers not defined for platform.  Skipping module.')
+        self.res = ModuleResult.NOTAPPLICABLE
+        return False
 
     ##
     # Displays the SPI Regions Access Permissions
@@ -96,6 +105,7 @@ class spi_access(BaseModule):
             elif ModuleResult.FAILED == res:
                 self.logger.log_failed("SPI Flash Region Access Permissions are not programmed securely in flash descriptor")
                 self.logger.log_important('System may be using alternative protection by including descriptor region in SPI Protected Range Registers')
+                self.logger.log_important('If using alternative protections, this can be considered a WARNING')
             elif ModuleResult.WARNING == res:
                 self.logger.log_warning("Certain SPI flash regions are writeable by software")
         else:
@@ -104,11 +114,7 @@ class spi_access(BaseModule):
 
         return res
 
-    # --------------------------------------------------------------------------
-    # run( module_argv )
-    # Required function: run here all tests from this module
-    # --------------------------------------------------------------------------
-    def run( self, module_argv ):
+    def run(self, module_argv):
         self.logger.start_test("SPI Flash Region Access Control")
         self.spi.display_SPI_Ranges_Access_Permissions()
         self.res = self.check_flash_access_permissions()
