@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 
@@ -36,31 +36,32 @@ Usage:
 
 Note: the fuzzer is incompatible with native VMBus driver (``vmbus.sys``). To use it, remove ``vmbus.sys``
 """
-from chipsec.modules.tools.vmm.hv.define       import *
-from chipsec.modules.tools.vmm.hv.hypercall    import *
-from chipsec.module_common                     import *
+from chipsec.modules.tools.vmm.hv.define import *
+from chipsec.modules.tools.vmm.hv.hypercall import *
+from chipsec.module_common import *
 
 # Hypercall vectors excluded from scan/fuzzing
 excluded_hypercalls_from_scan = []
-excluded_hypercalls_from_fuzzing  = excluded_hypercalls_from_scan + [HV_POST_MESSAGE]
+excluded_hypercalls_from_fuzzing = excluded_hypercalls_from_scan + [HV_POST_MESSAGE]
+
 
 class HypercallFuzz(BaseModule):
 
     def usage(self):
-        print ('  Usage:')
-        print ('    chipsec_main.py -i -m tools.vmm.hv.hypercall [-a mode,vector,iterations]')
-        print ('      mode                fuzzing mode')
-        print ('        = status-fuzzing  finding parameters with hypercall success status')
-        print ('        = params-info     shows input parameters valid ranges')
-        print ('        = params-fuzzing  parameters fuzzing based on their valid ranges')
-        print ('        = custom-fuzzing  fuzzing of known hypercalls')
-        print ('      vector              hypercall vector')
-        print ('      iterations          number of hypercall iterations')
-        print ('  Note: the fuzzer is incompatible with native VMBus driver (vmbus.sys). To use it, remove vmbus.sys')
+        print('  Usage:')
+        print('    chipsec_main.py -i -m tools.vmm.hv.hypercall [-a mode,vector,iterations]')
+        print('      mode                fuzzing mode')
+        print('        = status-fuzzing  finding parameters with hypercall success status')
+        print('        = params-info     shows input parameters valid ranges')
+        print('        = params-fuzzing  parameters fuzzing based on their valid ranges')
+        print('        = custom-fuzzing  fuzzing of known hypercalls')
+        print('      vector              hypercall vector')
+        print('      iterations          number of hypercall iterations')
+        print('  Note: the fuzzer is incompatible with native VMBus driver (vmbus.sys). To use it, remove vmbus.sys')
         return
 
     def run(self, module_argv):
-        self.logger.start_test( "Hyper-V hypercall fuzzer" )
+        self.logger.start_test("Hyper-V hypercall fuzzer")
 
         if len(module_argv) > 0:
             command = module_argv[0]
@@ -80,7 +81,7 @@ class HypercallFuzz(BaseModule):
             hv.scan_partitionid(range(0x0, 0x100))
             hv.scan_connectionid(range(0x00000, 0x00100) + range(0x10000, 0x10100))
 
-            ## Scans for implemented hypercalls and discovers their interface
+            # Scans for implemented hypercalls and discovers their interface
             hypercalls_for_scanning = list(set(range(0x100)) - set(excluded_hypercalls_from_scan))
             hv.scan_hypercalls(hypercalls_for_scanning)
 
@@ -91,17 +92,17 @@ class HypercallFuzz(BaseModule):
 
         if command == 'info':
             if hv.hypervisor_present:
-                ## Print Synthetic MSRs
+                # Print Synthetic MSRs
                 hv.print_synthetic_msrs()
 
-                ## Print Partition IDs
+                # Print Partition IDs
                 hv.print_partitionid()
 
-                ## Print Connection IDs
+                # Print Connection IDs
                 hv.print_connectionid([])
                 hv.print_partition_properties()
 
-                ## Print discovered hypercalls and their interface
+                # Print discovered hypercalls and their interface
                 hv.print_hypercall_status()
 
         elif command == 'status-fuzzing':
