@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 
@@ -23,37 +23,51 @@
 Hyper-V VMBus generic fuzzer
 
 Usage:
-    ``chipsec_main.py -i -m tools.vmm.hv.vmbusfuzz -a fuzz,<parameters> -l log.txt``
+    ``chipsec_main.py -i -m tools.vmm.hv.vmbusfuzz -a fuzz,<parameters>``
 
     Parameters:
 
-    - ``all``          fuzzing all bytes
-    - ``hv``           fuzzing HyperV message header
-    - ``vmbus``        fuzzing HyperV message body / VMBUS message
-    - ``<pos>,<size>`` fuzzing number of bytes at specific position
+    - ``all``          : Fuzzing all bytes
+    - ``hv``           : Fuzzing HyperV message header
+    - ``vmbus``        : Fuzzing HyperV message body / VMBUS message
+    - ``<pos>,<size>`` : Fuzzing number of bytes at specific position
+
+Examples:
+    >>> chipsec_main.py -i -m tools.vmm.hv.vmbusfuzz -a fuzz,all -l log.txt
+
+.. note::
+    - The fuzzer is incompatible with native VMBus driver (``vmbus.sys``). To use it, remove ``vmbus.sys``
+    - Returns a Warning by default
+    - System may be in an unknown state, further evaluation may be needed
+
+.. important::
+    - This module is designed to run in a VM environment
+    - Behavior on physical HW is undefined
 
-Note: the fuzzer is incompatible with native VMBus driver (``vmbus.sys``). To use it, remove ``vmbus.sys``
 """
-from struct import *
-from random import *
-from chipsec.modules.tools.vmm.hv.define import *
-from chipsec.modules.tools.vmm.common    import *
-from chipsec.modules.tools.vmm.hv.vmbus  import *
-import chipsec_util
+
+import sys
+import traceback
+from struct import pack
+from random import getrandbits, choice
+from chipsec.module_common import ModuleResult
+from chipsec.modules.tools.vmm.common import session_logger, overwrite, get_int_arg
+from chipsec.modules.tools.vmm.hv.vmbus import VMBusDiscovery, HyperV, RingBuffer
 
 sys.stdout = session_logger(True, 'vmbusfuzz')
 
+
 class VMBusFuzz(VMBusDiscovery):
     def __init__(self):
         VMBusDiscovery.__init__(self)
-        self.training         = False
+        self.training = False
         self.training_msginfo = []
-        self.fuzzing          = False
-        self.fuzzing_rules    = {}
-        self.current_message  = 0
+        self.fuzzing = False
+        self.fuzzing_rules = {}
+        self.current_message = 0
 
     ##
-    ##  hv_post_msg - Fuzzing a message to be sent
+    # hv_post_msg - Fuzzing a message to be sent
     ##
     def hv_post_msg(self, message):
         if self.training:
@@ -64,8 +78,8 @@ class VMBusFuzz(VMBusDiscovery):
                 for position in rules:
                     message = overwrite(message, rules[position], position)
             self.current_message += 1
-        ## Randomize leftover bytes. It shouldn't affect functionality.
-        leftovers = ''.join(chr(getrandbits(8)) for i in range(256 - len(message)))
+        # Randomize leftover bytes. It shouldn't affect functionality.
+        leftovers = ''.join(chr(getrandbits(8)) for _ in range(256 - len(message)))
         return HyperV.hv_post_msg(self, message + leftovers)
 
     def vmbus_test1_run(self):
@@ -96,27 +110,14 @@ class VMBusFuzz(VMBusDiscovery):
             self.vmbus_teardown_gpadl(relid, self.ringbuffers[relid].gpadl)
 
         self.vmbus_rescind_all_offers()
-        #if not self.fuzzing:
-        #for i in self.ringbuffers:
-        #    self.ringbuffers[i].ringbuffer_free()
-
-    def usage(self):
-        self.logger.log('  Usage:')
-        self.logger.log('    chipsec_main.py -i -m tools.vmm.hv.vmbusfuzz -a fuzz,<parameters>')
-        self.logger.log('      parameters:')
-        self.logger.log('        all          fuzzing all bytes')
-        self.logger.log('        hv           fuzzing HyperV message header')
-        self.logger.log('        vmbus        fuzzing HyperV message body / VMBUS message')
-        self.logger.log('        <pos>,<size> fuzzing number of bytes at specific position')
-        self.logger.log('  Note: the fuzzer is incompatible with native VMBus driver (vmbus.sys). To use it, remove vmbus.sys')
 
     def run(self, module_argv):
-        self.logger.start_test( "Hyper-V VMBus fuzzer" )
+        self.logger.start_test("Hyper-V VMBus fuzzer")
 
         if len(module_argv) > 0:
             command = module_argv[0]
         else:
-            self.usage()
+            self.logger.log(self.__doc__.replace('`', ''))
             return
 
         cmdarg1 = module_argv[1] if len(module_argv) > 1 else 'all'
@@ -158,9 +159,13 @@ class VMBusFuzz(VMBusDiscovery):
                         self.fuzzing = False
                     m += 1
         except KeyboardInterrupt:
-            print ('***** Control-C *****')
-        except Exception as error:
+            self.logger.log('***** Control-C *****')
+        except Exception:
             traceback.print_exc()
         finally:
             self.vmbus_rescind_all_offers()
-        return ModuleResult.PASSED
+
+        self.logger.log_information('Module completed')
+        self.logger.log_warning('System may be in an unknown state, further evaluation may be needed.')
+        self.res = ModuleResult.WARNING
+        return self.res
