@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2018-2019, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2018-2019, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 import json
@@ -26,6 +26,7 @@ import chipsec.file
 from chipsec.logger import logger
 from chipsec.defines import bytestostring
 
+
 def get_json_results(json_file):
     file_data = chipsec.file.read_file(json_file)
     if file_data == 0:
@@ -33,10 +34,11 @@ def get_json_results(json_file):
     try:
         json_data = json.loads(bytestostring(file_data))
     except:
-        logger().error("Unable to load JSON file: {}".format(json_file))
+        logger().log_error(f'Unable to load JSON file: {json_file}')
         return None
     return json_data
 
+
 def compute_result_deltas(previous, current):
     deltas = {}
     all_tests = set(current)
@@ -55,25 +57,27 @@ def compute_result_deltas(previous, current):
             deltas[test] = {'previous': prev_res, 'current': new_res}
     return deltas
 
+
 def display_deltas(deltas, hide_time, start_time):
-    logger().log( "" )
-    logger().log( "[CHIPSEC] **********************  TEST DELTA SUMMARY  *********************" )
+    logger().log("")
+    logger().log("[CHIPSEC] **********************  TEST DELTA SUMMARY  *********************")
     if not hide_time:
-        logger().log( "[CHIPSEC] Time elapsed          {:.3f}" .format(time.time() -start_time) )
+        logger().log(f'[CHIPSEC] Time elapsed          {time.time() - start_time:.3f}')
     if deltas:
-        logger().log( "[*] {:46}| {:10} | {:10}".format("Test", "Previous", "Current") )
-        logger().log( "[*] {}".format('-' * 71) )
+        logger().log(f'[*] {"Test":46}| {"Previous":10} | {"Current":10}')
+        logger().log(f'[*] {"-" * 71}')
         for test in deltas:
-            logger().log_bad("{:46}| {:10} | {:10}".format(test, deltas[test]['previous'], deltas[test]['current']))
+            logger().log_bad(f'{test:46}| {deltas[test]["previous"]:10} | {deltas[test]["current"]:10}')
     else:
-        logger().log_good( "No changes detected." )
-    logger().log( "[CHIPSEC] *****************************************************************" )
+        logger().log_good("No changes detected.")
+    logger().log("[CHIPSEC] *****************************************************************")
 
 
 def log_deltas_json(deltas, outfile):
     deltas_json = json.dumps(deltas, sort_keys=True, indent=2, separators=(',', ': '))
     chipsec.file.write_file(outfile, deltas_json)
 
+
 def log_deltas_xml(deltas, outfile):
     xml_deltas = ET.ElementTree(ET.Element('deltas'))
     delta_root = xml_deltas.getroot()
