@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 
@@ -47,12 +47,14 @@ import time
 
 from chipsec.command import BaseCommand
 from chipsec.defines import ALIGNED_4KB, BOUNDARY_4KB, bytestostring
-from chipsec_util    import get_option_width, is_option_valid_width, CMD_OPTS_WIDTH
-from chipsec.file    import read_file, write_file, get_main_dir
-from chipsec.logger  import print_buffer
-from argparse        import ArgumentParser
+from chipsec_util import get_option_width, is_option_valid_width, CMD_OPTS_WIDTH
+from chipsec.file import read_file, write_file, get_main_dir
+from chipsec.logger import print_buffer
+from argparse import ArgumentParser
 
 # Physical Memory
+
+
 class MemCommand(BaseCommand):
 
     def requires_driver(self):
@@ -101,7 +103,8 @@ class MemCommand(BaseCommand):
         return True
 
     def dump_region_to_path(self, path, pa_start, pa_end):
-        if pa_start >= pa_end: return
+        if pa_start >= pa_end:
+            return
         head_len = pa_start & ALIGNED_4KB
         tail_len = pa_end & ALIGNED_4KB
         pa = pa_start - head_len + ALIGNED_4KB + 1
@@ -109,7 +112,7 @@ class MemCommand(BaseCommand):
         end = pa_end - tail_len
         with open(fname, 'wb') as f:
             # read leading bytes to the next boundary
-            if (head_len > 0 ):
+            if (head_len > 0):
                 f.write(self.cs.mem.read_physical_mem(pa_start, ALIGNED_4KB + 1 - head_len))
 
             for addr in range(pa, end, ALIGNED_4KB + 1):
@@ -120,31 +123,31 @@ class MemCommand(BaseCommand):
                 f.write(self.cs.mem.read_physical_mem(end, tail_len))
 
     def mem_allocate(self):
-        (va, pa) = self.cs.mem.alloc_physical_mem( self.allocate_length )
-        self.logger.log( '[CHIPSEC] Allocated {:X} bytes of physical memory: VA = 0x{:016X}, PA = 0x{:016X}'.format(self.allocate_length, va, pa) )
+        (va, pa) = self.cs.mem.alloc_physical_mem(self.allocate_length)
+        self.logger.log('[CHIPSEC] Allocated {:X} bytes of physical memory: VA = 0x{:016X}, PA = 0x{:016X}'.format(self.allocate_length, va, pa))
 
     def mem_search(self):
-        buffer = self.cs.mem.read_physical_mem( self.phys_address, self.length )
+        buffer = self.cs.mem.read_physical_mem(self.phys_address, self.length)
         buffer = bytestostring(buffer)
         offset = buffer.find(self.value)
 
         if (offset != -1):
-            self.logger.log( '[CHIPSEC] Search buffer from memory: PA = 0x{:016X}, len = 0x{:X}, target address= 0x{:X}..'.format(self.phys_address, self.length, self.phys_address + offset) )
+            self.logger.log('[CHIPSEC] Search buffer from memory: PA = 0x{:016X}, len = 0x{:X}, target address= 0x{:X}..'.format(self.phys_address, self.length, self.phys_address + offset))
         else:
-            self.logger.log( '[CHIPSEC] Search buffer from memory: PA = 0x{:016X}, len = 0x{:X}, can not find the target in the searched range..'.format(self.phys_address, self.length) )
+            self.logger.log('[CHIPSEC] Search buffer from memory: PA = 0x{:016X}, len = 0x{:X}, can not find the target in the searched range..'.format(self.phys_address, self.length))
 
     def mem_pagedump(self):
         end = self.start_address + self.length
-        self.dump_region_to_path( get_main_dir(), self.start_address, end )
+        self.dump_region_to_path(get_main_dir(), self.start_address, end)
 
     def mem_read(self):
-        self.logger.log( '[CHIPSEC] Reading buffer from memory: PA = 0x{:016X}, len = 0x{:X}..'.format(self.phys_address, self.buffer_length) )
-        buffer = self.cs.mem.read_physical_mem( self.phys_address, self.buffer_length )
+        self.logger.log('[CHIPSEC] Reading buffer from memory: PA = 0x{:016X}, len = 0x{:X}..'.format(self.phys_address, self.buffer_length))
+        buffer = self.cs.mem.read_physical_mem(self.phys_address, self.buffer_length)
         if self.file_name:
-            write_file( self.file_name, buffer )
-            self.logger.log( "[CHIPSEC] Written 0x{:X} bytes to '{}'".format(len(buffer), self.file_name) )
+            write_file(self.file_name, buffer)
+            self.logger.log("[CHIPSEC] Written 0x{:X} bytes to '{}'".format(len(buffer), self.file_name))
         else:
-            print_buffer( bytestostring(buffer) )
+            print_buffer(bytestostring(buffer))
 
     def mem_readval(self):
         width = 0x4
@@ -153,56 +156,62 @@ class MemCommand(BaseCommand):
             try:
                 width = get_option_width(self.length) if is_option_valid_width(self.length) else int(self.length, 16)
             except ValueError:
-                self.logger.error("[CHIPSEC] Bad length given '{}'".format(self.length))
+                self.logger.log_error("[CHIPSEC] Bad length given '{}'".format(self.length))
                 return
 
-        if width not in (0x1,0x2,0x4):
-            self.logger.error( "Must specify <length> argument in 'mem readval' as one of {}".format(CMD_OPTS_WIDTH) )
+        if width not in (0x1, 0x2, 0x4):
+            self.logger.log_error("Must specify <length> argument in 'mem readval' as one of {}".format(CMD_OPTS_WIDTH))
             return
-        self.logger.log( '[CHIPSEC] Reading {:X}-byte value from PA 0x{:016X}..'.format(width, self.phys_address) )
-        if   0x1 == width: value = self.cs.mem.read_physical_mem_byte ( self.phys_address )
-        elif 0x2 == width: value = self.cs.mem.read_physical_mem_word ( self.phys_address )
-        elif 0x4 == width: value = self.cs.mem.read_physical_mem_dword( self.phys_address )
-        self.logger.log( '[CHIPSEC] Value = 0x{:X}'.format(value) )
+        self.logger.log('[CHIPSEC] Reading {:X}-byte value from PA 0x{:016X}..'.format(width, self.phys_address))
+        if 0x1 == width:
+            value = self.cs.mem.read_physical_mem_byte(self.phys_address)
+        elif 0x2 == width:
+            value = self.cs.mem.read_physical_mem_word(self.phys_address)
+        elif 0x4 == width:
+            value = self.cs.mem.read_physical_mem_dword(self.phys_address)
+        self.logger.log('[CHIPSEC] Value = 0x{:X}'.format(value))
 
     def mem_write(self):
-        if not os.path.exists( self.buffer_data ):
+        if not os.path.exists(self.buffer_data):
             try:
                 buffer = bytearray.fromhex(self.buffer_data)
             except ValueError:
-                self.logger.error( "Incorrect <value> specified: '{}'".format(self.buffer_data) )
+                self.logger.log_error("Incorrect <value> specified: '{}'".format(self.buffer_data))
                 return
-            self.logger.log( "[CHIPSEC] Read 0x{:X} hex bytes from command-line: '{}'".format(len(buffer), self.buffer_data) )
+            self.logger.log("[CHIPSEC] Read 0x{:X} hex bytes from command-line: '{}'".format(len(buffer), self.buffer_data))
         else:
-            buffer = read_file( self.buffer_data )
-            self.logger.log( "[CHIPSEC] Read 0x{:X} bytes from file '{}'".format(len(buffer), self.buffer_data) )
+            buffer = read_file(self.buffer_data)
+            self.logger.log("[CHIPSEC] Read 0x{:X} bytes from file '{}'".format(len(buffer), self.buffer_data))
 
         if len(buffer) < self.buffer_length:
-            self.logger.error( "Number of bytes read (0x{:X}) is less than the specified <length> (0x{:X})".format(len(buffer), self.buffer_length) )
+            self.logger.log_error("Number of bytes read (0x{:X}) is less than the specified <length> (0x{:X})".format(len(buffer), self.buffer_length))
             return
 
-        self.logger.log( '[CHIPSEC] writing buffer to memory: PA = 0x{:016X}, len = 0x{:X}..'.format(self.phys_address, self.buffer_length) )
-        self.cs.mem.write_physical_mem( self.phys_address, self.buffer_length, buffer )
+        self.logger.log('[CHIPSEC] writing buffer to memory: PA = 0x{:016X}, len = 0x{:X}..'.format(self.phys_address, self.buffer_length))
+        self.cs.mem.write_physical_mem(self.phys_address, self.buffer_length, buffer)
 
     def mem_writeval(self):
-            try:
-                width = get_option_width(self.length) if is_option_valid_width(self.length) else int(self.length, 16)
-            except ValueError:
-                self.logger.error( "Must specify <length> argument in 'mem writeval' as one of {}".format(CMD_OPTS_WIDTH) )
-                return
-
-            if width not in (0x1,0x2,0x4):
-                self.logger.error( "Must specify <length> argument in 'mem writeval' as one of {}".format(CMD_OPTS_WIDTH) )
-                return
-            self.logger.log( '[CHIPSEC] Writing {:X}-byte value 0x{:X} to PA 0x{:016X}..'.format(width, self.write_data, self.phys_address) )
-            if   0x1 == width: self.cs.mem.write_physical_mem_byte ( self.phys_address, self.write_data )
-            elif 0x2 == width: self.cs.mem.write_physical_mem_word ( self.phys_address, self.write_data )
-            elif 0x4 == width: self.cs.mem.write_physical_mem_dword( self.phys_address, self.write_data )
+        try:
+            width = get_option_width(self.length) if is_option_valid_width(self.length) else int(self.length, 16)
+        except ValueError:
+            self.logger.log_error("Must specify <length> argument in 'mem writeval' as one of {}".format(CMD_OPTS_WIDTH))
+            return
 
+        if width not in (0x1, 0x2, 0x4):
+            self.logger.log_error("Must specify <length> argument in 'mem writeval' as one of {}".format(CMD_OPTS_WIDTH))
+            return
+        self.logger.log('[CHIPSEC] Writing {:X}-byte value 0x{:X} to PA 0x{:016X}..'.format(width, self.write_data, self.phys_address))
+        if 0x1 == width:
+            self.cs.mem.write_physical_mem_byte(self.phys_address, self.write_data)
+        elif 0x2 == width:
+            self.cs.mem.write_physical_mem_word(self.phys_address, self.write_data)
+        elif 0x4 == width:
+            self.cs.mem.write_physical_mem_dword(self.phys_address, self.write_data)
 
     def run(self):
         t = time.time()
         self.func()
-        self.logger.log( "[CHIPSEC] (mem) time elapsed {:.3f}".format(time.time() -t) )
+        self.logger.log("[CHIPSEC] (mem) time elapsed {:.3f}".format(time.time() - t))
 
-commands = { 'mem': MemCommand }
+
+commands = {'mem': MemCommand}
