@@ -1,28 +1,28 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 
 """
 CHIPSEC includes functionality for reading and writing the SPI flash. When an image file is created from reading the SPI flash, this image can be parsed to reveal sections, files, variables, etc.
 
-.. warning:: Particular care must be taken when using the spi write and spi erase functions. These could make your system unbootable.
+.. warning:: Particular care must be taken when using the SPI write and SPI erase functions. These could make your system unbootable.
 
 A basic forensic operation might be to dump the entire SPI flash to a file. This is accomplished as follows:
 
@@ -48,8 +48,8 @@ import time
 import os
 from chipsec.command import BaseCommand
 from chipsec.hal.spi import SPI, BIOS
-from chipsec.exceptions   import SpiRuntimeError
-from argparse        import ArgumentParser
+from chipsec.exceptions import SpiRuntimeError
+from argparse import ArgumentParser
 
 
 # SPI Flash Controller
@@ -94,60 +94,60 @@ class SPICommand(BaseCommand):
         return True
 
     def spi_info(self):
-        self.logger.log( "[CHIPSEC] SPI flash memory information\n" )
+        self.logger.log("[CHIPSEC] SPI flash memory information\n")
         self._spi.display_SPI_map()
 
     def spi_dump(self):
-        self.logger.log( "[CHIPSEC] Dumping entire SPI flash memory to '{}'".format(self.out_file) )
-        self.logger.log( "[CHIPSEC] {}".format(self._msg) )
+        self.logger.log("[CHIPSEC] Dumping entire SPI flash memory to '{}'".format(self.out_file))
+        self.logger.log("[CHIPSEC] {}".format(self._msg))
         # @TODO: don't assume SPI Flash always ends with BIOS region
-        (base, limit, _) = self._spi.get_SPI_region( BIOS )
+        (base, limit, _) = self._spi.get_SPI_region(BIOS)
         spi_size = limit + 1
-        self.logger.log( "[CHIPSEC] BIOS region: base = 0x{:08X}, limit = 0x{:08X}".format(base, limit) )
-        self.logger.log( "[CHIPSEC] Dumping 0x{:08X} bytes (to the end of BIOS region)".format(spi_size) )
-        buf = self._spi.read_spi_to_file( 0, spi_size, self.out_file )
-        if (buf is None):
-            self.logger.error( "Dumping SPI Flash didn't return any data (turn on VERBOSE)" )
+        self.logger.log("[CHIPSEC] BIOS region: base = 0x{:08X}, limit = 0x{:08X}".format(base, limit))
+        self.logger.log("[CHIPSEC] Dumping 0x{:08X} bytes (to the end of BIOS region)".format(spi_size))
+        buf = self._spi.read_spi_to_file(0, spi_size, self.out_file)
+        if buf is None:
+            self.logger.log_error("Dumping SPI Flash didn't return any data (turn on VERBOSE)")
         else:
-            self.logger.log( "[CHIPSEC] Completed SPI flash dump to '{}'".format(self.out_file) )
+            self.logger.log("[CHIPSEC] Completed SPI flash dump to '{}'".format(self.out_file))
 
     def spi_read(self):
-        self.logger.log( "[CHIPSEC] Reading 0x{:x} bytes from SPI Flash starting at FLA = 0x{:X}".format(self.length, self.spi_fla) )
-        self.logger.log( "[CHIPSEC] {}".format(self._msg) )
-        buf = self._spi.read_spi_to_file( self.spi_fla, self.length, self.out_file )
-        if (buf is None):
-            self.logger.error( "SPI flash read didn't return any data (turn on VERBOSE)" )
+        self.logger.log("[CHIPSEC] Reading 0x{:x} bytes from SPI Flash starting at FLA = 0x{:X}".format(self.length, self.spi_fla))
+        self.logger.log("[CHIPSEC] {}".format(self._msg))
+        buf = self._spi.read_spi_to_file(self.spi_fla, self.length, self.out_file)
+        if buf is None:
+            self.logger.log_error("SPI flash read didn't return any data (turn on VERBOSE)")
         else:
-            self.logger.log( "[CHIPSEC] Completed SPI flash memory read" )
+            self.logger.log("[CHIPSEC] Completed SPI flash memory read")
 
     def spi_write(self):
         if not os.path.exists(self.filename):
-            self.logger.error( "File '{}' doesn't exist".format(self.filename))
+            self.logger.log_error("File '{}' doesn't exist".format(self.filename))
             return
-        self.logger.log( "[CHIPSEC] Writing to SPI flash memory at FLA = 0x{:X} from '{:64s}'".format(self.spi_fla, self.filename) )
+        self.logger.log("[CHIPSEC] Writing to SPI flash memory at FLA = 0x{:X} from '{:64s}'".format(self.spi_fla, self.filename))
 
-        if self._spi.write_spi_from_file( self.spi_fla, self.filename ):
-            self.logger.log( "[CHIPSEC] Completed SPI flash memory write" )
+        if self._spi.write_spi_from_file(self.spi_fla, self.filename):
+            self.logger.log("[CHIPSEC] Completed SPI flash memory write")
         else:
-            self.logger.warn( "SPI flash write returned error (turn on VERBOSE)" )
+            self.logger.log_warning("SPI flash write returned error (turn on VERBOSE)")
 
     def spi_erase(self):
-        self.logger.log( "[CHIPSEC] Erasing SPI flash memory block at FLA = 0x{:X}".format(self.spi_fla) )
+        self.logger.log("[CHIPSEC] Erasing SPI flash memory block at FLA = 0x{:X}".format(self.spi_fla))
 
-        if self._spi.erase_spi_block( self.spi_fla ):
-            self.logger.log_result( "Completed SPI flash memory erase" )
+        if self._spi.erase_spi_block(self.spi_fla):
+            self.logger.log_good("Completed SPI flash memory erase")
         else:
-            self.logger.warn( "SPI flash erase returned error (turn on VERBOSE)" )
+            self.logger.log_warning("SPI flash erase returned error (turn on VERBOSE)")
 
     def spi_disable_wp(self):
-        self.logger.log( "[CHIPSEC] Trying to disable BIOS write protection.." )
+        self.logger.log("[CHIPSEC] Trying to disable BIOS write protection..")
         #
         # This write protection only matters for BIOS range in SPI flash memory
         #
         if self._spi.disable_BIOS_write_protection():
-            self.logger.log_good( "BIOS region write protection is disabled in SPI flash" )
+            self.logger.log_good("BIOS region write protection is disabled in SPI flash")
         else:
-            self.logger.log_bad( "Couldn't disable BIOS region write protection in SPI flash" )
+            self.logger.log_bad("Couldn't disable BIOS region write protection in SPI flash")
 
     def spi_sfdp(self):
         self._spi.get_SPI_SFDP()
@@ -156,31 +156,32 @@ class SPICommand(BaseCommand):
         if self.option.lower() == 'decode':
             (jedec, man, part) = self._spi.get_SPI_JEDEC_ID_decoded()
             if jedec is not False:
-                self.logger.log( '    JEDEC ID     : 0x{:06X}'.format(jedec) )
-                self.logger.log( '    Manufacturer : 0x{:02X}     - {}'.format( (jedec >> 16) & 0xFF, man) )
-                self.logger.log( '    Device       : 0x{:04X}   - {}'.format(jedec & 0xFFFF, part) )
-                self.logger.log( '' )
+                self.logger.log('    JEDEC ID     : 0x{:06X}'.format(jedec))
+                self.logger.log('    Manufacturer : 0x{:02X}     - {}'.format((jedec >> 16) & 0xFF, man))
+                self.logger.log('    Device       : 0x{:04X}   - {}'.format(jedec & 0xFFFF, part))
+                self.logger.log('')
             else:
-                self.logger.log( ' JEDEC ID command is not supported ')
+                self.logger.log(' JEDEC ID command is not supported')
         else:
             jedec_id = self._spi.get_SPI_JEDEC_ID()
             if jedec_id is not False:
-                self.logger.log( '    JEDEC ID: 0x{:06X}'.format(jedec_id) )
-                self.logger.log( '' )
+                self.logger.log('    JEDEC ID: 0x{:06X}'.format(jedec_id))
+                self.logger.log('')
             else:
-                self.logger.log( ' JEDEC ID command is not supported ')
+                self.logger.log(' JEDEC ID command is not supported')
 
     def run(self):
         try:
-            self._spi = SPI( self.cs )
+            self._spi = SPI(self.cs)
         except SpiRuntimeError as msg:
-            self.logger.error(msg)
+            self.logger.log_error(msg)
             return
 
         self._msg = "it may take a few minutes (use DEBUG or VERBOSE logger options to see progress)"
         t = time.time()
         self.func()
 
-        self.logger.log( "[CHIPSEC] (spi) time elapsed {:.3f}".format(time.time() -t) )
+        self.logger.log("[CHIPSEC] (spi) time elapsed {:.3f}".format(time.time() - t))
 
-commands = { 'spi': SPICommand }
+
+commands = {'spi': SPICommand}
