@@ -1,21 +1,21 @@
-#CHIPSEC: Platform Security Assessment Framework
-#Copyright (c) 2010-2021, Intel Corporation
+# CHIPSEC: Platform Security Assessment Framework
+# Copyright (c) 2010-2021, Intel Corporation
 #
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU General Public License
-#as published by the Free Software Foundation; Version 2.
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; Version 2.
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-#Contact information:
-#chipsec@intel.com
+# Contact information:
+# chipsec@intel.com
 #
 
 
@@ -46,12 +46,12 @@ Examples:
 import os
 import chipsec_util
 
-from chipsec.command  import BaseCommand
-from chipsec.hal      import virtmem
-from chipsec.defines  import bytestostring
-from chipsec.logger   import print_buffer
-from chipsec.file     import write_file, read_file
-from argparse         import ArgumentParser
+from chipsec.command import BaseCommand
+from chipsec.hal import virtmem
+from chipsec.defines import bytestostring
+from chipsec.logger import print_buffer
+from chipsec.file import write_file, read_file
+from argparse import ArgumentParser
 
 
 # Virtual Memory
@@ -100,21 +100,19 @@ class VMemCommand(BaseCommand):
         parser.parse_args(self.argv[2:], namespace=self)
         return True
 
-
     def vmem_read(self):
-        self.logger.log( '[CHIPSEC] Reading buffer from memory: VA = 0x{:016X}, len = 0x{:X}.'.format(self.virt_address, self.size) )
+        self.logger.log('[CHIPSEC] Reading buffer from memory: VA = 0x{:016X}, len = 0x{:X}.'.format(self.virt_address, self.size))
         try:
-            buffer = self._vmem.read_virtual_mem( self.virt_address, self.size )
+            buffer = self._vmem.read_virtual_mem(self.virt_address, self.size)
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
+            self.logger.log_error('Error mapping VA to PA.')
             return
 
         if self.buf_file:
-            write_file( self.buf_file, buffer )
-            self.logger.log( "[CHIPSEC] Written 0x{:X} bytes to '{}'".format(len(buffer), self.buf_file) )
+            write_file(self.buf_file, buffer)
+            self.logger.log("[CHIPSEC] Written 0x{:X} bytes to '{}'".format(len(buffer), self.buf_file))
         else:
-            print_buffer( bytestostring(buffer) )
-
+            print_buffer(bytestostring(buffer))
 
     def vmem_readval(self):
         width = 0x4
@@ -128,40 +126,41 @@ class VMemCommand(BaseCommand):
                 except:
                     width = 0
 
-        self.logger.log( '[CHIPSEC] Reading {:X}-byte value from VA 0x{:016X}.'.format(width, self.virt_address) )
+        self.logger.log('[CHIPSEC] Reading {:X}-byte value from VA 0x{:016X}.'.format(width, self.virt_address))
         try:
-            if   0x1 == width: value = self._vmem.read_virtual_mem_byte ( self.virt_address )
-            elif 0x2 == width: value = self._vmem.read_virtual_mem_word ( self.virt_address )
-            elif 0x4 == width: value = self._vmem.read_virtual_mem_dword( self.virt_address )
+            if 0x1 == width:
+                value = self._vmem.read_virtual_mem_byte(self.virt_address)
+            elif 0x2 == width:
+                value = self._vmem.read_virtual_mem_word(self.virt_address)
+            elif 0x4 == width:
+                value = self._vmem.read_virtual_mem_dword(self.virt_address)
             else:
-                self.logger.error( "Must specify <length> argument in 'mem readval' as one of {}".format(chipsec_util.CMD_OPTS_WIDTH) )
+                self.logger.log_error("Must specify <length> argument in 'mem readval' as one of {}".format(chipsec_util.CMD_OPTS_WIDTH))
                 return
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
+            self.logger.log_error('Error mapping VA to PA.')
             return
-        self.logger.log( '[CHIPSEC] value = 0x{:X}'.format(value) )
-
+        self.logger.log('[CHIPSEC] value = 0x{:X}'.format(value))
 
     def vmem_write(self):
-        if not os.path.exists( self.buf_file ):
+        if not os.path.exists(self.buf_file):
             try:
                 buffer = bytearray.fromhex(self.buf_file)
             except ValueError as e:
-                self.logger.error( "Incorrect <value> specified: '{}'".format(self.buf_file) )
-                self.logger.error( str(e) )
+                self.logger.log_error("Incorrect <value> specified: '{}'".format(self.buf_file))
+                self.logger.log_error(str(e))
                 return
-            self.logger.log( "[CHIPSEC] Read 0x{:X} hex bytes from command-line: {}'".format(len(buffer), self.buf_file) )
+            self.logger.log("[CHIPSEC] Read 0x{:X} hex bytes from command-line: {}'".format(len(buffer), self.buf_file))
         else:
-            buffer = read_file( self.buf_file )
-            self.logger.log( "[CHIPSEC] Read 0x{:X} bytes from file '{}'".format(len(buffer), self.buf_file) )
+            buffer = read_file(self.buf_file)
+            self.logger.log("[CHIPSEC] Read 0x{:X} bytes from file '{}'".format(len(buffer), self.buf_file))
 
         if len(buffer) < self.size:
-            self.logger.error( "Number of bytes read (0x{:X}) is less than the specified <length> (0x{:X})".format(len(buffer), self.size) )
+            self.logger.log_error("Number of bytes read (0x{:X}) is less than the specified <length> (0x{:X})".format(len(buffer), self.size))
             return
 
-        self.logger.log( '[CHIPSEC] Writing buffer to memory: VA = 0x{:016X}, len = 0x{:X}.'.format(self.virt_address, self.size) )
-        self._vmem.write_virtual_mem( self.virt_address, self.size, buffer )
-
+        self.logger.log('[CHIPSEC] Writing buffer to memory: VA = 0x{:016X}, len = 0x{:X}.'.format(self.virt_address, self.size))
+        self._vmem.write_virtual_mem(self.virt_address, self.size, buffer)
 
     def vmem_writeval(self):
         if chipsec_util.is_option_valid_width(self.length):
@@ -172,57 +171,56 @@ class VMemCommand(BaseCommand):
             except ValueError:
                 width = 0
 
-        self.logger.log( '[CHIPSEC] Writing {:X}-byte value 0x{:X} to VA 0x{:016X}..'.format(width, self.value, self.virt_address) )
+        self.logger.log('[CHIPSEC] Writing {:X}-byte value 0x{:X} to VA 0x{:016X}..'.format(width, self.value, self.virt_address))
         try:
-            if   0x1 == width: self._vmem.write_virtual_mem_byte ( self.virt_address, self.value )
-            elif 0x2 == width: self._vmem.write_virtual_mem_word ( self.virt_address, self.value )
-            elif 0x4 == width: self._vmem.write_virtual_mem_dword( self.virt_address, self.value )
+            if 0x1 == width:
+                self._vmem.write_virtual_mem_byte(self.virt_address, self.value)
+            elif 0x2 == width:
+                self._vmem.write_virtual_mem_word(self.virt_address, self.value)
+            elif 0x4 == width:
+                self._vmem.write_virtual_mem_dword(self.virt_address, self.value)
             else:
-                self.logger.error( "Must specify <length> argument in 'mem writeval' as one of {}".format(chipsec_util.CMD_OPTS_WIDTH) )
+                self.logger.log_error("Must specify <length> argument in 'mem writeval' as one of {}".format(chipsec_util.CMD_OPTS_WIDTH))
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
-
+            self.logger.log_error('Error mapping VA to PA.')
 
     def vmem_search(self):
         try:
-            buffer = self._vmem.read_virtual_mem( self.virt_address, self.size )
+            buffer = self._vmem.read_virtual_mem(self.virt_address, self.size)
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
+            self.logger.log_error('Error mapping VA to PA.')
             return
 
         buffer = bytestostring(buffer)
         offset = buffer.find(self.value)
 
-        self.logger.log( "[CHIPSEC] Search buffer for '{}':".format(self.value) )
-        self.logger.log( '          VA = 0x{:016X}, len = 0x{:X}'.format(self.virt_address, self.size) )
+        self.logger.log("[CHIPSEC] Search buffer for '{}':".format(self.value))
+        self.logger.log('          VA = 0x{:016X}, len = 0x{:X}'.format(self.virt_address, self.size))
         if offset != -1:
-            self.logger.log( '[CHIPSEC] Target address = 0x{:X}.'.format(self.virt_address + offset) )
+            self.logger.log('[CHIPSEC] Target address = 0x{:X}.'.format(self.virt_address + offset))
         else:
-            self.logger.log( '[CHIPSEC] Could not find the target in the searched range.' )
-
+            self.logger.log('[CHIPSEC] Could not find the target in the searched range.')
 
     def vmem_allocate(self):
         try:
-            (va, pa) = self._vmem.alloc_virtual_mem( self.size )
+            (va, pa) = self._vmem.alloc_virtual_mem(self.size)
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
+            self.logger.log_error('Error mapping VA to PA.')
             return
-        self.logger.log( '[CHIPSEC] Allocated {:X} bytes of virtual memory:'.format(self.size) )
-        self.logger.log( '          VA = 0x{:016X}'.format(va) )
-        self.logger.log( '          PA = 0x{:016X}'.format(pa) )
-
+        self.logger.log('[CHIPSEC] Allocated {:X} bytes of virtual memory:'.format(self.size))
+        self.logger.log('          VA = 0x{:016X}'.format(va))
+        self.logger.log('          PA = 0x{:016X}'.format(pa))
 
     def vmem_getphys(self):
         try:
-            pa = self._vmem.va2pa( self.virt_address )
+            pa = self._vmem.va2pa(self.virt_address)
         except (TypeError, OSError):
-            self.logger.error( 'Error mapping VA to PA.' )
+            self.logger.log_error('Error mapping VA to PA.')
             return
         if pa is not None:
-            self.logger.log( '[CHIPSEC] Virtual memory:' )
-            self.logger.log( '          VA = 0x{:016X}'.format(self.virt_address) )
-            self.logger.log( '          PA = 0x{:016X}'.format(pa) )
-
+            self.logger.log('[CHIPSEC] Virtual memory:')
+            self.logger.log('          VA = 0x{:016X}'.format(self.virt_address))
+            self.logger.log('          PA = 0x{:016X}'.format(pa))
 
     def run(self):
         try:
@@ -233,4 +231,4 @@ class VMemCommand(BaseCommand):
         self.func()
 
 
-commands = { 'vmem': VMemCommand }
+commands = {'vmem': VMemCommand}
